      DOUBLE PRECISION FUNCTION CUM(I,X)                                        
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC        
C                                                                      C        
C     CUM                                                              C        
C                                                                      C        
C     DESCRIPTION                                                      C        
C         CUMULATIVE DISTRIBUTION OF THE VARIABLES                     C        
C                                                                      C        
C     DESCRIPTION OF ARGUMENTS                                         C        
C         INPUT                                                        C        
C           I      - VARIABLE NUMBER                                   C        
C           X      -                                                   C        
C                                                                      C        
C         OUTPUT                                                       C        
C           CUM                                                        C        
C                                                                      C        
C     CALLED BY ASSIGN, EQUDIV, FINVC                                  C        
C                                                                      C        
C     USES ERF, ERFC                                                   C        
C                                                                      C        
C                                                                      C        
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC        
C                                                                               
      INCLUDE  'par.h'                                                          
      INCLUDE  'cparam.h'                                                       
      INCLUDE  'cvaria.h'                                                       
C                                                                               
C                   LOCAL DIMENSION                                             
C                   ===============                                             
C                                                                               
      REAL*8     MEAN,SIG,SIGMWB,GAMMWB,BETAWB                                  
      REAL*4     RAN(MXNINT)                                                    
C                                                                               
C                                                                               
      NINT1=NINT(I)+1                                                           
      NINTI=NINT(I)                                                             
      IF(ITYPE(I).EQ.1.OR.ITYPE(I).EQ.2) THEN                                   
          IF(ITYPE(I).EQ.1) THEN                                                
              IF( NINT1.GT.100 )  THEN                                          
                  WRITE(6,9002)  NINT1                                          
                  STOP                                                          
              ENDIF                                                             
              DO  10 J=1,NINT1                                                  
                  RAN(J)=RANGE(I,J)                                             
   10         CONTINUE                                                          
          ELSE                                                                  
              DO  20 J=1,NINT1                                                  
                  RAN(J)=LOG10(RANGE(I,J))                                      
   20         CONTINUE                                                          
          ENDIF                                                                 
          DO  40 JI=1,NINTI                                                     
              IF(X.GE.RAN(JI).AND.X.LE.RAN(JI+1)) THEN                          
                  CUM=0.                                                        
                  JIM=JI-1                                                      
                  IF(JIM.GT.0) THEN                                             
                      DO 30 L=1,JIM                                             
                           CUM=CUM+WEIGHT(I,L)                                  
   30                 CONTINUE                                                  
                  ENDIF                                                         
                  CUM=CUM+(X-RAN(JI))*                                          
     &                WEIGHT(I,JI)/(RAN(JI+1)-RAN(JI))                          
                  RETURN                                                        
              ENDIF                                                             
  40      CONTINUE                                                              
          CUM=1.                                                                
          RETURN                                                                
      ELSEIF(ITYPE(I).EQ.3) THEN                                                
          CUM=WEIGHT(I,1)*X**2/2.                                               
          RETURN                                                                
      ELSEIF(ITYPE(I).EQ.4.OR.ITYPE(I).EQ.5) THEN                               
          SIG=RANGE(I,1)                                                        
          MEAN=RANGE(I,2)                                                       
          UU=(X-MEAN)/SIG/SQRT(2.)                                              
          IF(UU.LT.0.) CUM=ERFC(ABS(UU))/2.                                     
          IF(UU.GE.0.) CUM=(1.+ERF(UU))/2.                                      
          RETURN                                                                
      ELSEIF(ITYPE(I).EQ.6) THEN                                                
          SIGMWB=RANGE(I,1)                                                     
          GAMMWB=RANGE(I,2)                                                     
          BETAWB=RANGE(I,3)                                                     
          ET=(X-GAMMWB)/SIGMWB                                                  
          IF(ET.LT.0.) THEN                                                     
              WRITE(6,9000) X,GAMMWB,SIGMWB                                     
          ENDIF                                                                 
          ARG=ET**BETAWB                                                        
          CUM=1. - EXP(-ARG)                                                    
          RETURN                                                                
      ELSE                                                                      
          WRITE(6,9001) ITYPE(I)                                                
          STOP                                                                  
      ENDIF                                                                     
C                                                                               
C                             FORMAT                                            
C                             ======                                            
C                                                                               
 9000 FORMAT(' X      = ',E12.3,/,                                              
     &       ' GAMMWB = ',D12.3,/,                                              
     &       ' SIGMWB = ',D12.3)                                                
 9001 FORMAT('*** CUM *** WRONG ITYPE ; ITYPE = ',I5)                           
 9002 FORMAT('*** CUM *** NINT1 IS GREATER THAN MXNINT; NINT1 = ',I5)           
      END                                                                       
