      SUBROUTINE  EQUDIV
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                                                      C
C     EQUDIV                                                           C
C                                                                      C
C     DESCRIPTION                                                      C
C         SUBROUTINE FOR SUBDIVISION OF THE VARIABLES                  C
C         DISTRIBUTIONS INTO INTERVALS OF EQUAL PROBABILITY            C
C                                                                      C
C     DESCRIPTION OF VARIABLES                                         C
C         INPUT                                                        C
C           NVARS  - NUMBER OF VARIABLES                               C
C           NRUNS  - NUMBER OF RUNS                                    C
C           DITR   - TRUNCATION VALUE                                  C
C           ITYPE  - TYPE OF PROBABILITY DISTRIBUTION FUNCTION         C
C           NINT   - NUMBER OF INTERVALS                               C
C           RANGE  - DISTRIBUTION PARAMETERS                           C
C           WEIGHT - STATISTICAL WEIGHT OF INTERVAL                    C
C                                                                      C
C         OUTPUT                                                       C
C           XX(NVARS,NRUNS+1) - INTERVALS SUBDIVISION MATRIX           C
C                                                                      C
C     CALLED BY MAIN                                                   C
C                                                                      C
C     USES CUM, FINVC                                                  C
C                                                                      C
C                                                                      C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C
      INCLUDE 'par.h'
      INCLUDE 'cparam.h'
      INCLUDE 'cvaria.h'
      INCLUDE 'cchara.h'
C
C                   LOCAL DIMENSION
C                   ===============
C
      DOUBLE PRECISION CUM,FINVC
      DOUBLE PRECISION CPS
      REAL*4     RANG(MXNINT+1)
C
      DRUN=1./FLOAT(NRUNS)
      NRP1=NRUNS+1

      DO  110  I=1,NVARS
C
C
C                   UNIFORM OR LOGUNIFORM
C                   =====================
C
          IF(ITYPE(I).EQ.1.OR.ITYPE(I).EQ.2) THEN

              NN=NINT(I)+1

              IF(ITYPE(I).EQ.1) THEN

                  DO  10 J=1,NN
                      RANG(J)=RANGE(I,J)
   10             CONTINUE
              ELSE
                  DO  20 J=1,NN
                      RANG(J)=ALOG10(RANGE(I,J))
   20             CONTINUE
              ENDIF
C
C                             CHECK THAT RANGE > 0
C                             ====================
C                       I.E. IS VARIABILITY WANTED FOR THIS PARAMETER ?
C
              IF(RANGE(I,1).EQ.RANGE(I,2)) THEN
                  DO 30 J=1,NRP1
                      XX(I,J)=RANG(NN)
   30             CONTINUE
              ELSE
                  XX(I,1)=RANG(1)
                  CP=0.
                  K=1
                  DO  60  J=2,NRP1
                      CP=CP+DRUN
                      IF(CP.GE.1) CP=.999999
                      W=WEIGHT(I,1)
                      IF(CP.GT.W) THEN
                         DO 40 K=2,NINT(I)
                             W=W+WEIGHT(I,K)
                             IF(CP.LE.W) GO TO 50
   40                    CONTINUE
   50                    CONTINUE
                      ENDIF
                      XX(I,J)=RANG(K)+(CP-CUM(I,RANG(K)))*
     &                  (RANG(K+1)-RANG(K))/WEIGHT(I,K)
   60             CONTINUE
              ENDIF

C
C
C                   NORMAL OR LOGNORMAL
C                   ===================
C
          ELSEIF(ITYPE(I).EQ.4.OR.ITYPE(I).EQ.5) THEN

C
C                             CHECK THAT RANGE > 0
C                             ====================
C                       I.E. IS VARIABILITY WANTED FOR THIS PARAMETER ?
C

              IF(RANGE(I,1).LE.0.) THEN
                  DO 70 J=1,NRP1
                      XX(I,J)=RANG(2)
   70             CONTINUE
              ELSE
C
C                             START FROM THE MIDDLE
C                             =====================
C
c                  NH=NRUNS/2
c                  NM=NH+1
c                  XX(I,NM)=RANGE(I,2)
c                  CP=.5
c                  DO 80 J=1,NH
c                     CP=CP+DRUN
C
C                             SCALE FOR THE
C                             TRUNCATION VALUE
C                             ================
C
c                     CPS=CP*(1-DITR)+DITR/2.
c                     NP=NM+J
c                     NL=NM-J
C stefano 18 03 97
                  NH=(NRUNS+1)/2
                  NM=NH+1
                  XX(I,NH)=RANGE(I,2)
                  XX(I,NM)=RANGE(I,2)
c                  XX(I,NH)=RANG(2)
c                  XX(I,NM)=RANG(2)
                  CP=.5
                  DO 80 J=1,NH-1
                     CP=CP+DRUN
C
C                             SCALE FOR THE
C                             TRUNCATION VALUE
C                             ================
C
                     CPS=CP*(1-DITR)+DITR/2.
                     NP=NM+J
                     NL=NH-J
                     IF( ((1.-CPS).LT.1.E-4.AND.CPS.LT.1.).OR.
     &                   (CPS.GE.1) )  THEN
                          XX(I,NP)=XX(I,NP-1)
     &                            + 2.*(XX(I,NP-1)-XX(I,NP-2))
                      ELSE
                          XX(I,NP)=FINVC(I,CPS,XX(I,NP-1))
                      ENDIF
                      XX(I,NL)=XX(I,NM) - (XX(I,NP)-XX(I,NM))
   80             CONTINUE
c	      IF (ITYPE(I).EQ.5) THEN
c	        DO J=1,NRP1
c	          XX(I,J)=10**(XX(I,J))
c	        END DO
c	      END IF
            ENDIF
C
C
C                   SAW TOOTH
C                   =========
C
          ELSEIF(ITYPE(I).EQ.3) THEN
              XX(I,1)=0.
              CP=0
              DO  90 J=2,NRP1
                  CP=CP+DRUN
                  XX(I,J)=SQRT(CP/WEIGHT(I,1))
   90         CONTINUE
C
C
C                   WEIBULL
C                   =======
C
          ELSEIF(ITYPE(I).EQ.6) THEN
              CP=0.
              CPS=CP*(1-DITR)+DITR/2.
              START=RANGE(I,2) + 0.01
              XX(I,1)=FINVC(I,CPS,START)
              DO 100 J=2,NRP1
                  CP=CP+DRUN
C
C                             SCALE FOR THE
C                             TRUNCATION VALUE
C                             ================
C
                  CPS=CP*(1-DITR)+DITR/2.
                  XX(I,J)=FINVC(I,CPS,XX(I,J-1))
  100         CONTINUE
          ELSE
              WRITE(6,9000) ITYPE(I)
              STOP
          ENDIF
  110 CONTINUE
C
C
C                   PRINT INTERVAL SUBDIVISION MATRIX
C                   =================================
C
c      C A L L   P R T I S M (NVARS,MXNVAR,NRUNS,FVFLD,XX)
C
      RETURN
C
C                             FORMAT
C                             ======
C
 9000 FORMAT('0***** WRONG ITYPE ; ITYPE = ',I5)
      END
